@@ -390,12 +390,12 @@ void Child_Done(int sig)
 
 
 #ifdef FREEBSD
-int getjiffies(int pid)
+long getjiffies(int pid)
 {
    kvm_t *my_kernel = NULL;
    struct kinfo_proc *process_data = NULL;
    int processes;
-   int my_jiffies = -1;
+   long my_jiffies = -1;
 
    my_kernel = kvm_open(0, 0, 0, O_RDONLY, "kvm_open");
    if (! my_kernel)
@@ -418,7 +418,7 @@ int getjiffies(int pid)
 
 #ifdef LINUX
 //get jiffies count from /proc filesystem
-int getjiffies(int pid) {
+long getjiffies(int pid) {
 	static char stat[20];
 	static char buffer[1024];
         char *p;
@@ -435,10 +435,10 @@ int getjiffies(int pid) {
 	  while (sp--)
 		p=memchr(p+1,' ',sizeof(buffer)-(p-buffer));
 	  //user mode jiffies
-	  int utime=atoi(p+1);
+	  long utime=atol(p+1);
 	  p=memchr(p+1,' ',sizeof(buffer)-(p-buffer));
 	  //kernel mode jiffies
-	  int ktime=atoi(p+1);
+	  long ktime=atol(p+1);
 	  return utime+ktime;
         }
         // could not read info
@@ -450,7 +450,7 @@ int getjiffies(int pid) {
 //process instant photo
 struct process_screenshot {
 	struct timespec when;	//timestamp
-	int jiffies;	//jiffies count of the process
+	long jiffies;	//jiffies count of the process
 	int cputime;	//microseconds of work from previous screenshot to current
 };
 
@@ -483,7 +483,7 @@ int compute_cpu_usage(int pid,int last_working_quantum,struct cpu_usage *pusage)
 
 	//let's advance front index and save the screenshot
 	front=(front+1)%MEM_ORDER;
-	int j=getjiffies(pid);
+	long j=getjiffies(pid);
 	if (j>=0) ps[front].jiffies=j;
 	else return -1;	//error: pid does not exist
 
@@ -521,7 +521,7 @@ int compute_cpu_usage(int pid,int last_working_quantum,struct cpu_usage *pusage)
 			dtwork+=ps[i].cputime;
 			i=(i+1)%MEM_ORDER;
 		} while (i!=max);
-		int used=ps[front].jiffies-ps[tail].jiffies;
+		long used=ps[front].jiffies-ps[tail].jiffies;
 		float usage=(used*1000000.0/HZ)/dtwork;
 		pusage->workingrate=1.0*dtwork/dt;
 		pusage->pcpu=usage*pusage->workingrate;
@@ -779,9 +779,14 @@ void *Monitor_Children(void *all_data)
                     printf("Starting monitor with: %s -l %s -p %s -z -m\n",
                             program_data->this_program, limit_amount,
                             process_identifier);
-                 execl(program_data->this_program, program_data->this_program,
+                 execlp(program_data->this_program, program_data->this_program,
                        "-l", limit_amount, "-p", process_identifier, 
                        "-z", "-m", (char *) NULL);
+                 // we should not return, report error and bail out
+                 if (verbose)
+                   printf("Error trying to execute %s\n", program_data->this_program);
+                 exit(1);
+                  
               }
               
          }    // end of creating a new monitor
